@@ -13,7 +13,7 @@ class SalesforceMetadataFetcherAsync:
 
     async def get_sobject_describe(self, obj, cache=True):
         if not cache or not self._cache_sobject.get(obj):
-            self._cache_sobject[obj] = (await self.client.get(f'sobjects/{obj}/describe')).json()
+            self._cache_sobject[obj] = (await self.client.get(f'sobjects/{obj}/describe', timeout=10.0)).json()
         return self._cache_sobject.get(obj)
 
     async def get_picklist_values(self, obj, field):
@@ -35,7 +35,7 @@ class SalesforceMetadataFetcherAsync:
 
     async def get_all_sobjects(self, cache=True):
         if not cache or not self._cache_sobjects_list:
-            self._cache_sobjects_list = (await self.client.get("sobjects")).json()['sobjects']
+            self._cache_sobjects_list = (await self.client.get("sobjects", timeout=10.0)).json()['sobjects']
         return self._cache_sobjects_list
 
     async def get_all_sobject_request_coroutines(self, unfiltered=True, cache=True):
